@@ -1,4 +1,4 @@
-# main 77
+# main 78
 # sam robson
 
 
@@ -32,15 +32,14 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("77.9.9", package_name="alacorder")
+@click.version_option("78.0.1", package_name="alacorder")
 def cli():
     """
-    ALACORDER beta 77.9
+    ALACORDER beta 78
 
     Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
 
     """
-    from alacorder import gui
 
 
 @cli.command(help="Export data tables from archive or directory")
